#%% Imports
import pandas as pd
import os
from jgtpy import JGTPDSP as pds


#%% Functions

def crop_dataframe(df,crop_last_dt:str=None, crop_start_dt:str=None):
    if crop_last_dt is not None:
        df = df[df.index <= crop_last_dt]
    if crop_start_dt is not None:
        df = df[df.index >= crop_start_dt]
    return df

def calculate_target_variable_min_max(dfsrc, crop_last_dt=None, crop_start_dt=None, WINDOW_MIN=1, WINDOW_MAX=150, set_index=True, rounder=2,pipsize=-1):
    df = dfsrc.copy()
    
    df = crop_dataframe(df, crop_last_dt, crop_start_dt)
    
    
    #reset index before we iterate
    try:
        df.reset_index(drop=False, inplace=True)
    except:
        pass
    
    # Initialize the tmax and tmin columns with NaN values
    df['tmax'] = float('nan')
    df['tmin'] = float('nan')
    df['p'] = float('nan')
    df['l'] = float('nan')
    df['target'] = float('nan')

    # Calculate the maximum and minimum Close value in the window range for each row
    for i in range(WINDOW_MIN, len(df) - WINDOW_MAX):
        #FDBS
        if df.loc[i, 'fdbs'] == 1.0 :
            df.loc[i, 'tmax'] = df.loc[i:i+WINDOW_MAX, 'Close'].min()
            df.loc[i, 'tmin'] = df.loc[i:i+WINDOW_MAX, 'Close'].max()            
             
            if df.loc[i, 'High'] < df.loc[i, 'tmin']:
                df.loc[i, 'l'] = round(df.loc[i, 'High'] - df.loc[i, 'Low'], rounder)
                df.loc[i, 'target'] = round(-1 * (df.loc[i, 'High'] - df.loc[i, 'Low']), rounder)
            else:
                df.loc[i, 'p'] =  round(df.loc[i, 'Low'] - df.loc[i, 'tmax'], rounder)
                df.loc[i, 'target'] =  round(df.loc[i, 'Low'] - df.loc[i, 'tmax'], rounder)
        #FDBB    
        if df.loc[i, 'fdbb'] == 1.0:
            df.loc[i, 'tmax'] = df.loc[i:i+WINDOW_MAX, 'Close'].max()
            df.loc[i, 'tmin'] = df.loc[i:i+WINDOW_MAX, 'Close'].min()
            
            if df.loc[i, 'Low'] > df.loc[i, 'tmin']:
                df.loc[i, 'l'] = round(df.loc[i, 'High'] - df.loc[i, 'Low'], rounder)
                df.loc[i, 'target'] = round(-1*  (df.loc[i, 'High'] - df.loc[i, 'Low']), rounder)
            else:
                df.loc[i, 'p'] =round(df.loc[i, 'tmax'] - df.loc[i, 'High'] , rounder)
                df.loc[i, 'target'] =round(df.loc[i, 'tmax'] - df.loc[i, 'High'] , rounder)
            



    # Fill NaN with zero for columns tmax and tmin
    df['tmax']= df['tmax'].fillna(0)
    df['tmin']= df['tmin'].fillna(0)
    df['p']= df['p'].fillna(0)
    df['l']= df['l'].fillna(0)
    df['target']= df['target'].fillna(0)
    # After calculating the 'target' column
    if pipsize != -1:
        df['target'] = df['target'] / pipsize

    #@q Maybe set backnthe index !??
    if set_index:
        df.set_index('Date', inplace=True)
    return df





# jgtml
__version__ = '0.0.3'
import sys
import os

sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))

from calc import calculate_target_variable_min_max as calc_targets

#from jgtpy import JGTPDS as pds,JGTADS as ads,JGTPDSP as pds



#!/usr/bin/env Python
"""
jgtml
"""

from setuptools import find_packages, setup

from jgtml import __version__ as version

INSTALL_REQUIRES = [
    "pandas>=0.25.1",
    "python-dotenv>=0.19.2",
    #'kaleido>=0.2.1',
    "matplotlib>=3.3.1",
    "plotly>=5.18.0",
    "jgtpy>=0.3.21",
    "mplfinance>=0.12.10b0",
    "scipy>=1.7.3",
    "panel>=1.3.8",
]

EXTRAS_DEV_LINT = [
    "flake8>=3.6.0,<3.7.0",
    "isort>=4.3.4,<4.4.0",
]

EXTRAS_DEV_TEST = [
    "coverage",
    "pytest>=3.10",
]

EXTRAS_DEV_DOCS = [
    "readme_renderer",
    "sphinx",
    "sphinx_rtd_theme>=0.4.0",
    "html2text>=2020.1.16",
    "html2markdown>=0.1.7",
]

setup(
    name="jgtml",
    version=version,
    description="JGTrading Data maker' Dataframes",
    long_description=open("README.rst").read(),
    author="GUillaume Isabelle",
    author_email="jgi@jgwill.com",
    url="https://github.com/jgwill/jgtml",
    packages=find_packages(include=["jgtml"], exclude=["*test*"]),
    # packages=find_packages(include=['jgtml', 'jgtml.forexconnect', 'jgtml.forexconnect.lib', 'jgtml.forexconnect.lib.windows', 'jgtml.forexconnect.lib.linux'], exclude=['*test*']),
    install_requires=INSTALL_REQUIRES,
    entry_points={
        "console_scripts": ["jgtcli=jgtml.jgtcli:main"],
    },
    extras_require={
        "dev": (EXTRAS_DEV_LINT + EXTRAS_DEV_TEST + EXTRAS_DEV_DOCS),
        "dev-lint": EXTRAS_DEV_LINT,
        "dev-test": EXTRAS_DEV_TEST,
        "dev-docs": EXTRAS_DEV_DOCS,
    },
    license="MIT",
    keywords="data",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Financial and Insurance Industry",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python :: 3.7.16",
    ],
)
